# This file has been generated


build_system = 'AppVeyor'
build_id = '32133748'
build_number = '645'
build_version = '1.0.645'
job_id = 'yvkae4u2e7lq5sjb'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/pm/build/job/yvkae4u2e7lq5sjb'



# This file was automatically generated by sub\epyqlib\epyqlib\cli\generateversion.py
__version_build_time__ = '2020-04-13T02:05:19.995438'

__version__ = '2020.4.4'
__sha__ = '9ad431b905950d17317cda4666434ea95b74e89e'
__revision__ = '9ad431b905950d17317cda4666434ea95b74e89e'
